@@ -2,7 +2,7 @@ package Pandoc::Walker;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 use Scalar::Util qw(reftype blessed);
 use parent 'Exporter';
@@ -19,10 +19,11 @@ sub transform {
         foreach my $item (@$ast) {
             if ((reftype $item || '') eq 'HASH' and $item->{t}) {
                 my $res = $action->($item, @_);
+                # replace current item with result element(s)
                 if (defined $res) {
                     my @elements = map { transform($_, $action, @_) } 
                         (reftype $res || '') eq 'ARRAY' ? @$res : $res;
-                    splice @$ast, $i, $i+1, @elements;
+                    splice @$ast, $i, 1, @elements;
                     $i += scalar @elements;
                     next;
                 }
@@ -75,16 +76,16 @@ Pandoc::Walker - utility functions to traverse Pandoc documents
 
     # extract all links
     my $links = query $ast, sub {
-        my ($name, $value) = ($_[0]->name, $_[0]->content);
-        return unless ($name eq 'Link' or $name eq 'Image');
-        return $value->[1][0];
+        my $e = shift;
+        return unless ($e->name eq 'Link' or $e->name eq 'Image');
+        return $e->url;
     };
 
     # print all links
     walk $ast, sub {
-        my ($name, $value) = ($_[0]->name, $_[0]->content);
-        return unless ($key eq 'Link' or $key eq 'Image');
-        print $value->[1][0];
+        my $e = shift;
+        return unless ($e->name eq 'Link' or $e->name eq 'Image');
+        print $e->url;
     };
 
     # remove of all links
@@ -103,7 +104,25 @@ Pandoc::Walker - utility functions to traverse Pandoc documents
 =head1 DESCRIPTION
 
 This module provides to helper functions to traverse the abstract syntax tree
-of a pandoc document.
+(AST) of a pandoc document (see L<Pandoc::Elements> for documentation of AST
+elements).
+
+Document elements are passed to action functions by reference, so I<don't shoot
+yourself in the foot> by trying to directly modify the element. Traversing a single
+element is not reliable neither, so put the element in an array reference if needed.
+For instance to replace links in headers only by their link text content:
+
+    transform $ast, sub {
+        my $header = shift;
+        return unless $header->name eq 'Header';
+        transform [$header], sub { # make an array
+            my $link = shift;
+            return unless $link->name eq 'Link';
+            return $e->content;    # is an array
+        };
+    };
+
+See also L<Pandoc::Filter> for an object oriented interface to transformations.
 
 =head1 FUNCTIONS
 
@@ -125,24 +144,16 @@ keep it (if the action returns C<undef>), remove it (if it returns an empty
 array reference), or replace it with one or more elements (returned by array
 reference or as single value).
 
-=head1 AUTHOR
-
-Jakob Voß E<lt>jakob.voss@gbv.deE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2014- Jakob Voß
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+GNU General Public License, Version 2
+
+This module is heavily based on Pandoc by John MacFarlane.
 
 =head1 SEE ALSO
 
-L<Pandoc::Elements> for utility functions to build abstract syntax trees of
-pandoc documents.
-
-L<Pandoc::Filter> for a higher level application.
-
 Haskell module L<Text.Pandoc.Walk|http://hackage.haskell.org/package/pandoc-types/docs/Text-Pandoc-Walk.html> for the original.
 
 =cut
